@@ -151,8 +151,12 @@ def compute_digit_number(value):
     int
         number of digits
     """
-    first_nz = int(math.log10(abs(value)))
-    digit = abs(min(3,first_nz) - 3)
+    # fix for 0 value
+    if(value == 0):
+        first_nz = 1
+    else:
+        first_nz = int(math.log10(abs(value)))
+    digit = abs(min(3, first_nz) - 3)
     return digit
 
 def add_text(text_list,sep):
@@ -227,3 +231,14 @@ def compute_sorted_variables_interactions_list_indices(interaction_values):
 
     interaction_contrib_sorted_indices = np.dstack(np.unravel_index(np.argsort(tmp.ravel()), tmp.shape))[0][::-1]
     return interaction_contrib_sorted_indices
+
+
+def get_project_root():
+    """
+    Returns project root absolute path.
+    """
+    from pathlib import Path
+
+    current_path = Path(__file__)
+
+    return current_path.parent.parent.parent.resolve()
\ No newline at end of file
